A character string containing a field by which to order the results. One of name, city, state, c_code, fiscalyr, revenue, expenses,
sort
One of asc or desc, controlling the order of the results (according the the ordering given in order).
state
A two-letter state postal abbreviation code for a U.S. state or territory. Use ZZ for foreign organizations.
ntee
A numeric value (between 1 and 10) containing a http://nccs.urban.org/classification/NTEE.cfm{National Taxonomy of Exempt Entities (NTEE) Major Group} code.
subsection
A numeric value (between 2 and 92) referring to a subsection of tax code section 501(c).